@@ -8,9 +8,8 @@ from .repository import Repository
 
 
 class MemoryRepository(Repository, Generic[T]):
-
-    def __init__(self, locator: Locator = None,
-                 filterer: Filterer = None) -> None:
+    def __init__(self, filterer: Filterer = None,
+                 locator: Locator = None) -> None:
         self.data: Dict[str, Dict[str, T]] = defaultdict(dict)
         self.filterer: Filterer = filterer or DefaultFilterer()
         self.locator: Locator = locator or DefaultLocator()
